class LearningObjects::BuildController < ::ApplicationController
  layout 'learning_object_studio'

  include Wicked::Wizard
  before_action :set_learning_object, only: [:show, :update]

  steps :upload_attachments, :select_thumbnail

  def show
    render_wizard
  end

  def update
    @learning_object.update_attributes(learning_object_params)
    publish @learning_object if step == steps.last
    render_wizard @learning_object, notice: update_message
  end

  private

  def set_learning_object
    @learning_object = LearningObject.unscoped.find(params[:learning_object_id])
  end

  def publish(learning_object)
    learning_object.publish
    learning_object.save
  end

  def learning_object_params
    params[:learning_object].permit(:thumbnail, :name, :object_type_id, :description, :school_level, :language, :link, topics: [])
  end

  def update_message
    case step
      when :upload_attachments
        "Seus arquivos foram enviados com sucesso! Agora atualize a imagem do seu conteúdo para finalizar o processo de criação."
      when :select_thumbnail
        "Parabéns, a imagem foi atualizada e seu conteúdo foi criado com sucesso! Acesse seu perfil e veja todos os objetos criados."
    end
  end
end